﻿Type=Class
Version=3.82
B4A=true
@EndOfDesignText@
Sub Class_Globals
	Public MapWidth As Int 
	Public MapHeight As Int 
	Public TileWidth As Int 
	Public TileHeight As Int 
	Public LevelNum As Int 
	Public TileSize As Int 

	Type MapPoint(X As Int, Y As Int)
	
	Private MineMap As lgMapTiledMap
	Private MapRenderer As lgMapOrthogonalTiledMapRenderer
	Private mbOkToRender As Boolean = False 

	Private moDirtCapTiles(13) As lgMapStaticTiledMapTile 
	
	Private miScreenWidth As Int
	Private miScreenHeight As Int
	Private miTopGutter As Int
	Private miBottomGutter As Int
	
	Private moStage As lgScn2DStage 
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize(Level As Int, ScreenWidth As Int, ScreenHeight As Int, TopGutter As Float, BottomGutter As Float, Stage As lgScn2DStage)
	miScreenWidth = ScreenWidth
	miScreenHeight = ScreenHeight
	miTopGutter = TopGutter
	miBottomGutter = BottomGutter
	moStage = Stage
	LoadLevel(Level)
End Sub


Public Sub Dispose
	If MineMap <> Null Then
		MineMap.Dispose
	End If
	If MapRenderer.IsInitialized Then
		MapRenderer.Dispose
	End If 
End Sub


Public Sub LoadLevel(Level As Int)
	Dim piIndex As Int 
	
	LogColor("---- clsMap LoadLevel Begin", Colors.RGB(50, 200, 50))
	mbOkToRender = False
	LevelNum = Level 
	
	Log("dispose map render")	
	If MapRenderer.IsInitialized Then
		If MapRenderer <> Null Then
			MapRenderer.Dispose 
		End If
	End If 

	Log("dispose mine map")
	If MineMap <> Null Then
		MineMap.Dispose 
	End If 
	
	Log("Load new map")
	' load new map
	Dim TMXLoader As lgMapTmxMapLoader
	Dim psFile As String = "maps/map_" & NumberFormat(LevelNum, 3, 0) & ".tmx"
	MineMap = TMXLoader.Initialize2(psFile)
	
	Log("Load map properties")
	' number of tiles 
	MapWidth = MineMap.Properties.Get("width")
	MapHeight = MineMap.Properties.Get("height")
	' tile size in pixels
	TileWidth = MineMap.Properties.Get("tilewidth")
	TileHeight =  MineMap.Properties.Get("tileheight")
	
	Log("Dirt caps load")
	' Dirt cap tile references
	Dim poTiles As lgMapTiledMapSet 
	poTiles = MineMap.TileSets.getTileSet(0)
	For piIndex = 0 To poTiles.size - 1
		Dim poTile As lgMapStaticTiledMapTile
		poTile = poTiles.GetTile(piIndex)
		If poTile <> Null Then
			If poTile.Properties.containsKey("dirt") Then
				Dim piVal As Int 
				piVal = poTile.Properties.Get("dirt")
				If piVal >= 0 AND piVal < 12 Then
					moDirtCapTiles(piVal) = poTile
				End If
			End If
		End If 
	Next 
	Log("    Loaded " & moDirtCapTiles.Length & " dirt tiles")
		
	Log("initialize map render")		
	Dim RatioW As Float = miScreenWidth / (TileWidth * MapWidth)
	Dim RatioH As Float = (miScreenHeight - (miTopGutter + miBottomGutter)) / (TileHeight * MapHeight)
	If RatioW < RatioH Then
		MapRenderer.Initialize4(MineMap, RatioW, moStage.SpriteBatch)
		TileSize = MapRenderer.UnitScale * TileWidth
	Else
		MapRenderer.Initialize4(MineMap, RatioH, moStage.SpriteBatch)
		TileSize = MapRenderer.UnitScale * TileHeight
	End If
	LogColor("---- clsMap LoadLevel COMPLETE!", Colors.RGB(50, 200, 50))
	mbOkToRender = True 
End Sub 


'Draws the ground and objects layer
Public Sub DrawBackground(Camera As lgOrthographicCamera)
	If mbOkToRender = False Then
		Return
	End If
	
	MapRenderer.SetCameraView(Camera)
	' draw the background and objects
	
	MapRenderer.Render2(Array As Int(0, 1))
End Sub

' draws the top "dirt" layer
Public Sub DrawForeground(Camera As lgOrthographicCamera)
	If mbOkToRender = False Then
		Return
	End If 
	' draw the dirt layer
	MapRenderer.SetCameraView(Camera)
	MapRenderer.Render2(Array As Int(2))
End Sub

' draws all layers at once
Public Sub DrawAll(Camera As lgOrthographicCamera)
	MapRenderer.SetCameraView(Camera)
	MapRenderer.Render 
End Sub


